"""
Python module generated from Java source file org.bukkit.entity.SplashPotion

Java source file obtained from artifact spigot-api version 1.20.3-R0.1-20231207.085553-9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class SplashPotion(ThrownPotion):
    """
    Represents a thrown splash potion bottle

    Deprecated
    - splash status depends on only on the potion item.
    """


